@@ -11,13 +11,12 @@ use warnings;
 
 no warnings qw( uninitialized once );
 
-our $VERSION = '1.865';
+our $VERSION = '1.867';
 
 use threads;
 use threads::shared;
 
 use base 'MCE::Channel';
-use bytes;
 
 my $LF = "\012"; Internals::SvREADONLY($LF, 1);
 my $is_MSWin32 = ( $^O eq 'MSWin32' ) ? 1 : 0;
@@ -70,12 +69,7 @@ sub enqueue {
       MCE::Util::_sock_ready_w( $self->{p_sock} ) if $is_MSWin32;
 
       while ( @_ ) {
-         my $data;
-         if ( ref $_[0] || !defined $_[0] ) {
-            $data = $freeze->([ shift ]), $data .= '1';
-         } else {
-            $data = shift, $data .= '0';
-         }
+         my $data = $freeze->([ shift ]);
          print { $self->{p_sock} } pack('i', length $data), $data;
       }
    }
@@ -104,9 +98,7 @@ sub dequeue {
          MCE::Channel::_read( $self->{c_sock}, $data, $len );
       }
 
-      chop( $data )
-         ? wantarray ? @{ $thaw->($data) } : ( $thaw->($data) )->[-1]
-         : wantarray ? ( $data ) : $data;
+      wantarray ? @{ $thaw->($data) } : ( $thaw->($data) )->[-1];
    }
    else {
       my ( $plen, @ret );
@@ -125,7 +117,7 @@ sub dequeue {
             }
 
             MCE::Channel::_read( $self->{c_sock}, my($data), $len );
-            push @ret, chop($data) ? @{ $thaw->($data) } : $data;
+            push @ret, @{ $thaw->($data) };
          }
       }
 
@@ -154,7 +146,7 @@ sub dequeue_nb {
          }
 
          MCE::Channel::_read( $self->{c_sock}, my($data), $len );
-         push @ret, chop($data) ? @{ $thaw->($data) } : $data;
+         push @ret, @{ $thaw->($data) };
       }
    }
 
@@ -171,12 +163,7 @@ sub send {
    my $self = shift;
    return MCE::Channel::_ended('send') if $self->{ended};
 
-   my $data;
-   if ( @_ > 1 || ref $_[0] || !defined $_[0] ) {
-      $data = $freeze->([ @_ ]), $data .= '1';
-   } else {
-      $data = $_[0], $data .= '0';
-   }
+   my $data = $freeze->([ @_ ]);
 
    local $\ = undef if (defined $\);
 
@@ -207,9 +194,7 @@ sub recv {
       MCE::Channel::_read( $self->{c_sock}, $data, $len );
    }
 
-   chop( $data )
-      ? wantarray ? @{ $thaw->($data) } : ( $thaw->($data) )->[-1]
-      : wantarray ? ( $data ) : $data;
+   wantarray ? @{ $thaw->($data) } : ( $thaw->($data) )->[-1];
 }
 
 sub recv_nb {
@@ -231,9 +216,7 @@ sub recv_nb {
       MCE::Channel::_read( $self->{c_sock}, $data, $len );
    }
 
-   chop( $data )
-      ? wantarray ? @{ $thaw->($data) } : ( $thaw->($data) )->[-1]
-      : wantarray ? ( $data ) : $data;
+   wantarray ? @{ $thaw->($data) } : ( $thaw->($data) )->[-1];
 }
 
 ###############################################################################
@@ -244,13 +227,7 @@ sub recv_nb {
 
 sub send2 {
    my $self = shift;
-
-   my $data;
-   if ( @_ > 1 || ref $_[0] || !defined $_[0] ) {
-      $data = $freeze->([ @_ ]), $data .= '1';
-   } else {
-      $data = $_[0], $data .= '0';
-   }
+   my $data = $freeze->([ @_ ]);
 
    local $\ = undef if (defined $\);
    local $MCE::Signal::SIG;
@@ -294,9 +271,7 @@ sub recv2 {
          : read( $p_sock, $data, $len );
    }
 
-   chop( $data )
-      ? wantarray ? @{ $thaw->($data) } : ( $thaw->($data) )->[-1]
-      : wantarray ? ( $data ) : $data;
+   wantarray ? @{ $thaw->($data) } : ( $thaw->($data) )->[-1];
 }
 
 sub recv2_nb {
@@ -327,9 +302,7 @@ sub recv2_nb {
          : read( $p_sock, $data, $len );
    }
 
-   chop( $data )
-      ? wantarray ? @{ $thaw->($data) } : ( $thaw->($data) )->[-1]
-      : wantarray ? ( $data ) : $data;
+   wantarray ? @{ $thaw->($data) } : ( $thaw->($data) )->[-1];
 }
 
 1;
@@ -348,7 +321,7 @@ MCE::Channel::Threads - Channel for producer(s) and many consumers
 
 =head1 VERSION
 
-This document describes MCE::Channel::Threads version 1.865
+This document describes MCE::Channel::Threads version 1.867
 
 =head1 DESCRIPTION
 
