@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized once );
 
-our $VERSION = '1.864';
+our $VERSION = '1.867';
 
 use base 'MCE::Mutex';
 use Scalar::Util qw(refaddr weaken);
@@ -70,7 +70,7 @@ sub new {
 
     ($^O eq 'MSWin32')
         ? MCE::Util::_pipe_pair(\%obj, qw(_r_sock _w_sock))
-        : MCE::Util::_sock_pair(\%obj, qw(_r_sock _w_sock));
+        : MCE::Util::_sock_pair(\%obj, qw(_r_sock _w_sock), undef, 1);
 
     syswrite $obj{_w_sock}, '0';
 
@@ -139,7 +139,7 @@ MCE::Mutex::Channel - Mutex locking via a pipe or socket
 
 =head1 VERSION
 
-This document describes MCE::Mutex::Channel version 1.864
+This document describes MCE::Mutex::Channel version 1.867
 
 =head1 DESCRIPTION
 
